//---------------------------------------------------------------------------
#ifndef TDirectDrawCapsH
#define TDirectDrawCapsH

// ==========================================================================
// File:            TDDCaps.H
// Description:
//
// (c) 1998 A.S.C. Alternate Software Concepts, Sydney, Australia.
// All Rights Reserved. Refer to the file TDirectX_Licence.Txt for detailed
// licence & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
// include the basic TDirectDraw definitions
//---------------------------------------------------------------------------
#include "TDirectDrawInclude.h"
#include "TDirectDrawDefs.h"
#include "TDirectDrawErrors.h"

// --------------------------------------------------------------------------
// include the various DirectX Component classes used by TDDCaps
//---------------------------------------------------------------------------
#include "TDirectDrawSurface.h"

// ==========================================================================
// Class:           TDDCaps
// Description:     This object represents the capabilities of the hardware
//                  exposed through the TDirectDraw object
// Note:            This object contains a TDDSCaps object used in this
//                  context to describe what kinds of TDirectDrawSurface
//                  objects can be created. It may not be possible to
//                  simultaneously create all of the surfaces described by
//                  these capabilities
//                  This object is used with the TDirectDraw::GetCaps method
// ==========================================================================
class TDDCaps : public TPersistent
{
__published:
public:

// --------------------------------------------------------------------------
// Property:        Caps
// Description:     Driver specific capabilities
// --------------------------------------------------------------------------
    __property      dword                      Caps = { read=FGetCaps,
                                                        write=FSetCaps,         //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        Caps2
// Description:     More driver specific capabilities
// --------------------------------------------------------------------------
    __property      dword                     Caps2 = { read=FGetCaps2,
                                                        write=FSetCaps2,        //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        CKeyCaps
// Description:     Color-key capabilities
// --------------------------------------------------------------------------
    __property      dword                  CKeyCaps = { read=FGetCKeyCaps,
                                                        write=FSetCKeyCaps,     //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        FXCaps
// Description:     Driver-specific stretching and effects capabilities
// --------------------------------------------------------------------------
    __property      dword                    FXCaps = { read=FGetFXCaps,
                                                        write=FSetFXCaps,       //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        FXAlphaCaps
// Description:     Driver-specific alpha capabilities
// --------------------------------------------------------------------------
    __property      dword               FXAlphaCaps = { read=FGetFXAlphaCaps,
                                                        write=FSetFXAlphaCaps   //added write, default
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        PalCaps
// Description:     Palette capabilities
// --------------------------------------------------------------------------
    __property      dword                   PalCaps = { read=FGetPalCaps,
                                                        write=FSetPalCaps,      //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        SVCaps
// Description:     Stereo vision capabilities
// --------------------------------------------------------------------------
    __property      dword                    SVCaps = { read=FGetSVCaps,
                                                        write=FSetSVCaps,       //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        AlphaBltConstBitDepths
// Description:     DDBD_2, DDBD_4, or DDBD_8
// Note:            Indicates 2-, 4-, or 8-bits per pixel
// --------------------------------------------------------------------------
    __property      dword    AlphaBltConstBitDepths = {
                                        read=FGetAlphaBltConstBitDepths,
                                        write=FSetAlphaBltConstBitDepths,       //added write, default
                                        nodefault };

// --------------------------------------------------------------------------
// Property:        AlphaBltPixelBitDepths
// Description:     DDBD_1, DDBD_2, DDBD_4, or DDBD_8
// Note:            Indicates 1-, 2-, 4-, or 8-bits per pixel
// --------------------------------------------------------------------------
    __property      dword    AlphaBltPixelBitDepths = {
                                        read=FGetAlphaBltPixelBitDepths,
                                        write=FSetAlphaBltPixelBitDepths,       //added write, default
                                        nodefault };
// --------------------------------------------------------------------------
// Property:        AlphaBltSurfaceBitDepths
// Description:     DDBD_1, DDBD_2, DDBD_4, or DDBD_8
// Note:            Indicates 1-, 2-, 4-, or 8-bits per pixel
// --------------------------------------------------------------------------
    __property      dword  AlphaBltSurfaceBitDepths = {
                                        read=FGetAlphaBltSurfaceBitDepths,
                                        write=FSetAlphaBltSurfaceBitDepths,     //added write, default
                                        nodefault };

// --------------------------------------------------------------------------
// Property:        AlphaOverlayConstBitDepths
// Description:     DDBD_2, DDBD_4, or DDBD_8
// Note:            Indicates 2-, 4-, or 8-bits per pixel
// --------------------------------------------------------------------------
    __property      dword
                         AlphaOverlayConstBitDepths = {
                                    read=FGetAlphaOverlayConstBitDepths,
                                    write=FSetAlphaOverlayConstBitDepths,       //added write, default
                                    nodefault };

// --------------------------------------------------------------------------
// Property:        AlphaOverlayPixelBitDepths
// Description:     DDBD_1, DDBD_2, DDBD_4, or DDBD_8
// Note:            Indicates 1-, 2-, 4-, or 8-bits per pixel
// --------------------------------------------------------------------------
    __property      dword
                         AlphaOverlayPixelBitDepths = {
                                    read=FGetAlphaOverlayPixelBitDepths,
                                    write=FSetAlphaOverlayPixelBitDepths,       //added write, default
                                    nodefault };

// --------------------------------------------------------------------------
// Property:        AlphaOverlaySurfaceBitDepths
// Description:     DDBD_1, DDBD_2, DDBD_4, or DDBD_8
// Note:            Indicates 1-, 2-, 4-, or 8-bits per pixel
// --------------------------------------------------------------------------
    __property      dword
                       AlphaOverlaySurfaceBitDepths = {
                                    read=FGetAlphaOverlaySurfaceBitDepths,
                                    write=FSetAlphaOverlaySurfaceBitDepths,     //added write, default
                                    nodefault };

// --------------------------------------------------------------------------
// Property:        ZBufferBitDepths
// Description:     DDBD_8, DDBD_16, or DDBD_24
// Note:            Indicates 8-, 16-, 24-bits per pixel. 32-bit z-buffers
//                  are not supported
// --------------------------------------------------------------------------
    __property      dword          ZBufferBitDepths = {
                                                read=FGetZBufferBitDepths,
                                                write=FSetZBufferBitDepths,     //added write, default
                                                nodefault };

// --------------------------------------------------------------------------
// Property:        VidMemTotal
// Description:     Total amount of display memory
// --------------------------------------------------------------------------
    __property      dword               VidMemTotal = { read=FGetVidMemTotal,
                                                        write=FSetVidMemTotal   //added write, default
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        VidMemFree
// Description:     Amount of free display memory
// --------------------------------------------------------------------------
    __property      dword                VidMemFree = { read=FGetVidMemFree,
                                                        write=FSetVidMemFree,   //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        MaxVisibleOverlays
// Description:     Maximum number of visible overlays
// --------------------------------------------------------------------------
    __property      dword        MaxVisibleOverlays = {
                                            read=FGetMaxVisibleOverlays,
                                            write=FSetMaxVisibleOverlays,       //added write, default
                                            nodefault };

// --------------------------------------------------------------------------
// Property:        CurrVisibleOverlays
// Description:     Current number of visible overlays
// --------------------------------------------------------------------------
    __property      dword       CurrVisibleOverlays = {
                                            read=FGetCurrVisibleOverlays,
                                            write=FSetCurrVisibleOverlays,      //added write, default
                                            nodefault };

// --------------------------------------------------------------------------
// Property:        NumFourCCCodes
// Description:     Number of FourCC codes
// --------------------------------------------------------------------------
    __property      dword            NumFourCCCodes = {
                                                read=FGetNumFourCCCodes,
                                                write=FSetNumFourCCCodes,       //added write, default
                                                nodefault };

// --------------------------------------------------------------------------
// Property:        AlignBoundarySrc
// Description:     Source rectangle alignment for an overlay surface, in
//                  pixels
// --------------------------------------------------------------------------
    __property      dword          AlignBoundarySrc = {
                                                read=FGetAlignBoundarySrc,
                                                write=FSetAlignBoundarySrc,     //added write, default
                                                nodefault };

// --------------------------------------------------------------------------
// Property:        AlignSizeSrc
// Description:     Source rectangle size alignment for an overlay surface,
//                  in pixels
// Note:            Overlay source rectangles must have a pixel width that is
//                  a multiple of this value
// --------------------------------------------------------------------------
    __property      dword              AlignSizeSrc = {
                                                    read=FGetAlignSizeSrc,
                                                    write=FSetAlignSizeSrc,     //added write, default
                                                    nodefault };

// --------------------------------------------------------------------------
// Property:        AlignBoundaryDest
// Description:     Destination rectangle alignment for an overlay surface,
//                  in pixels
// --------------------------------------------------------------------------
    __property      dword         AlignBoundaryDest = {
                                                read=FGetAlignBoundaryDest,
                                                write=FSetAlignBoundaryDest,    //added write, default
                                                nodefault };

// --------------------------------------------------------------------------
// Property:        AlignSizeDest
// Description:     Destination rectangle size alignment for an overlay
//                  surface, in pixels
// Note:            Overlay destination rectangles must have a pixel width
//                  that is a multiple of this value
// --------------------------------------------------------------------------
    __property      dword             AlignSizeDest = {
                                                    read=FGetAlignSizeDest,
                                                    write=FSetAlignSizeDest,    //added write, default
                                                    nodefault };

// --------------------------------------------------------------------------
// Property:        AlignStrideAlign
// Description:     Stride alignment
// --------------------------------------------------------------------------
    __property      dword          AlignStrideAlign = {
                                                read=FGetAlignStrideAlign,
                                                write=FSetAlignStrideAlign,     //added write, default
                                                nodefault };

// --------------------------------------------------------------------------
// Property:        Rops0 through to Rops7
// Description:     Raster operations supported
// --------------------------------------------------------------------------
    __property      dword                     Rops0 = {
                                                    read=FGetRops, index=0 };

    __property      dword                     Rops1 = {
                                                    read=FGetRops,index=1 };

    __property      dword                     Rops2 = {
                                                    read=FGetRops,index=2 };

    __property      dword                     Rops3 = {
                                                    read=FGetRops,index=3 };
    __property      dword                     Rops4 = {
                                                    read=FGetRops,index=4 };
    __property      dword                     Rops5 = {
                                                    read=FGetRops,index=5 };
    __property      dword                     Rops6 = {
                                                    read=FGetRops,index=6 };
    __property      dword                     Rops7 = {
                                                    read=FGetRops,index=7 };

// --------------------------------------------------------------------------
// Property:        SurfaceCaps
// Description:     TSurfaceCaps object with general capabilities
// --------------------------------------------------------------------------
    __property      dword               SurfaceCaps = { read=FGetSurfaceCaps,
                                                        write=FSetSurfaceCaps   //added write, default
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        MinOverlayStretch
// Description:     Minimum overlay stretch factor multiplied by 1000
// --------------------------------------------------------------------------
    __property      dword         MinOverlayStretch = {
                                                read=FGetMinOverlayStretch,
                                                write=FSetMinOverlayStretch,    //added write, default
                                                nodefault };

// --------------------------------------------------------------------------
// Property:        MaxOverlayStretch
// Description:     Maximum overlay stretch factor multiplied by 1000
// --------------------------------------------------------------------------
    __property      dword         MaxOverlayStretch = {
                                                read=FGetMaxOverlayStretch,
                                                write=FSetMaxOverlayStretch,    //added write, default
                                                nodefault };

// --------------------------------------------------------------------------
// Property:        SVBCaps
// Description:     Driver-specific capabilities for system memory to display
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword                   SVBCaps = { read=FGetSVBCaps,
                                                        write=FSetSVBCaps,      //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        SVBCKeyCaps
// Description:     Driver color-key capabilities for system memory to
//                  display memory blits
// --------------------------------------------------------------------------
    __property      dword               SVBCKeyCaps = { read=FGetSVBCKeyCaps,
                                                        write=FSetSVBCKeyCaps   //added write, default
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        SVBFXCaps
// Description:     Driver FX capabilities for system memory to display
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword                 SVBFXCaps = { read=FGetSVBFXCaps,
                                                        write=FSetSVBFXCaps,    //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        SVBRops0 through to SVBRops7
// Description:     Raster operations supported for system memory to display
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword                  SVBRops0 = {
                                                read=FGetSVBRops,index=0 };
    __property      dword                  SVBRops1 = {
                                                read=FGetSVBRops,index=1 };
    __property      dword                  SVBRops2 = {
                                                read=FGetSVBRops,index=2 };
    __property      dword                  SVBRops3 = {
                                                read=FGetSVBRops,index=3 };
    __property      dword                  SVBRops4 = {
                                                read=FGetSVBRops,index=4 };
    __property      dword                  SVBRops5 = {
                                                read=FGetSVBRops,index=5 };
    __property      dword                  SVBRops6 = {
                                                read=FGetSVBRops,index=6 };
    __property      dword                  SVBRops7 = {
                                                read=FGetSVBRops,index=7 };

// --------------------------------------------------------------------------
// Property:        VSBCaps
// Description:     Driver-specific capabilities for display memory to system
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword                   VSBCaps = { read=FGetVSBCaps,
                                                        write=FSetVSBCaps,      //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        VSBCKeyCaps
// Description:     Driver color-key capabilities for display memory to
//                  system memory blits
// --------------------------------------------------------------------------
    __property      dword               VSBCKeyCaps = { read=FGetVSBCKeyCaps,
                                                        write=FSetVSBCKeyCaps   //added write, default
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        VSBFXCaps
// Description:     Driver FX capabilities for display memory to system
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword                 VSBFXCaps = { read=FGetVSBFXCaps,
                                                        write=FSetVSBFXCaps,    //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        VSBRops0 through to VSBRops7
// Description:     Raster operations supported for display memory to system
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword                  VSBRops0 = {
                                                read=FGetVSBRops,index=0 };
    __property      dword                  VSBRops1 = {
                                                read=FGetVSBRops,index=1 };
    __property      dword                  VSBRops2 = {
                                                read=FGetVSBRops,index=2 };
    __property      dword                  VSBRops3 = {
                                                read=FGetVSBRops,index=3 };
    __property      dword                  VSBRops4 = {
                                                read=FGetVSBRops,index=4 };
    __property      dword                  VSBRops5 = {
                                                read=FGetVSBRops,index=5 };
    __property      dword                  VSBRops6 = {
                                                read=FGetVSBRops,index=6 };
    __property      dword                  VSBRops7 = {
                                                read=FGetVSBRops,index=7 };

// --------------------------------------------------------------------------
// Property:        SSBCaps
// Description:     Driver-specific capabilities for system memory to system
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword                   SSBCaps = { read=FGetSSBCaps,
                                                        write=FSetSSBCaps,      //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        SSBCKeyCaps
// Description:     Driver color-key capabilities for system memory to system
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword               SSBCKeyCaps = { read=FGetSSBCKeyCaps,
                                                        write=FSetSSBCKeyCaps   //added write, default
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        SSBFXCaps
// Description:     Driver FX capabilities for system memory to system memory
//                  blits
// --------------------------------------------------------------------------
    __property      dword                 SSBFXCaps = { read=FGetSSBFXCaps,
                                                        write=FSetSSBFXCaps,    //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        SSBRops0 through to SSBRops7
// Description:     Raster operations supported for system memory to system
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword                  SSBRops0 = {
                                                read=FGetSSBRops,index=0 };
    __property      dword                  SSBRops1 = {
                                                read=FGetSSBRops,index=1 };
    __property      dword                  SSBRops2 = {
                                                read=FGetSSBRops,index=2 };
    __property      dword                  SSBRops3 = {
                                                read=FGetSSBRops,index=3 };
    __property      dword                  SSBRops4 = {
                                                read=FGetSSBRops,index=4 };
    __property      dword                  SSBRops5 = {
                                                read=FGetSSBRops,index=5 };
    __property      dword                  SSBRops6 = {
                                                read=FGetSSBRops,index=6 };
    __property      dword                  SSBRops7 = {
                                                read=FGetSSBRops,index=7 };

// --------------------------------------------------------------------------
// Property:        MaxVideoPorts
// Description:     Maximum number of live video ports
// --------------------------------------------------------------------------
    __property      dword             MaxVideoPorts = {
                                                    read=FGetMaxVideoPorts,
                                                    write=FSetMaxVideoPorts,    //added write, default
                                                    nodefault };

// --------------------------------------------------------------------------
// Property:        CurrVideoPorts
// Description:     Current number of live video ports
// --------------------------------------------------------------------------
    __property      dword            CurrVideoPorts = {
                                                read=FGetCurrVideoPorts,
                                                write=FSetCurrVideoPorts,       //added write, default
                                                nodefault };

// --------------------------------------------------------------------------
// Property:        SVBCaps2
// Description:     More driver-specific capabilities for system memory to
//                  video memory blits
// --------------------------------------------------------------------------
    __property      dword                  SVBCaps2 = { read=FGetSVBCaps2,
                                                        write=FSetSVBCaps2,     //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        NLVBCaps
// Description:     Driver-specific capabilities for nonlocal to local video
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword                  NLVBCaps = { read=FGetSVBCaps2,
                                                        write=FSetSVBCaps2,     //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        NLVBCaps2
// Description:     More driver-specific capabilities for nonlocal to local
//                  video memory blits
// --------------------------------------------------------------------------
    __property      dword                 NLVBCaps2 = { read=FGetNLVBCaps2,
                                                        write=FSetNLVBCaps2,    //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        NLVBCKeyCaps
// Description:     Driver color-key capabilities for nonlocal to local video
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword              NLVBCKeyCaps = {
                                                    read=FGetNLVBCKeyCaps,
                                                    write=FSetNLVBCKeyCaps,     //added write, default
                                                    nodefault };

// --------------------------------------------------------------------------
// Property:        NLVBFXCaps
// Description:     Driver FX capabilities for nonlocal to local video memory
//                  blits
// --------------------------------------------------------------------------
    __property      dword                NLVBFXCaps = { read=FGetNLVBFXCaps,
                                                        write=FSetNLVBFXCaps,   //added write, default
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        NLVBRops0 through to NLVBRops7
// Description:     Raster operations supported for nonlocal to local video
//                  memory blits
// --------------------------------------------------------------------------
    __property      dword                  NLVBRops0 = {
                                                read=FGetNLVBRops,index=0 };
    __property      dword                  NLVBRops1 = {
                                                read=FGetNLVBRops,index=1 };
    __property      dword                  NLVBRops2 = {
                                                read=FGetNLVBRops,index=2 };
    __property      dword                  NLVBRops3 = {
                                                read=FGetNLVBRops,index=3 };
    __property      dword                  NLVBRops4 = {
                                                read=FGetNLVBRops,index=4 };
    __property      dword                  NLVBRops5 = {
                                                read=FGetNLVBRops,index=5 };
    __property      dword                  NLVBRops6 = {
                                                read=FGetNLVBRops,index=6 };
    __property      dword                  NLVBRops7 = {
                                                read=FGetNLVBRops,index=7 };

// --------------------------------------------------------------------------
// Method:          Size
// Description:     This returns the size of the internal DDCAPS structure
// --------------------------------------------------------------------------
    dword       __fastcall  Size();

// --------------------------------------------------------------------------
// Method:          Ptr
// Description:     This property returns a pointer to the internal DDCaps
//                  structure
// --------------------------------------------------------------------------
    DDCAPS*             __fastcall  Ptr();

// --------------------------------------------------------------------------
// Constructor & Destructor
// --------------------------------------------------------------------------
                        __fastcall  TDDCaps();
    virtual             __fastcall  ~TDDCaps();

protected:

    dword               __fastcall  FGetCaps();
    void                __fastcall  FSetCaps( dword pCaps );                    //added Set
    dword               __fastcall  FGetCaps2();
    void                __fastcall  FSetCaps2( dword pCaps2 );                  //added Set
    dword               __fastcall  FGetCKeyCaps();
    void                __fastcall  FSetCKeyCaps( dword pCKeyCaps );            //added Set
    dword               __fastcall  FGetFXCaps();
    void                __fastcall  FSetFXCaps( dword pFXCaps );                //added Set
    dword               __fastcall  FGetFXAlphaCaps();
    void                __fastcall  FSetFXAlphaCaps( dword pFXAlphaCaps );      //added Set
    dword               __fastcall  FGetPalCaps();
    void                __fastcall  FSetPalCaps( dword pPalCaps );              //added Set
    dword               __fastcall  FGetSVCaps();
    void                __fastcall  FSetSVCaps( dword pSVCaps);                 //added Set
    dword               __fastcall  FGetAlphaBltConstBitDepths();
    void                __fastcall  FSetAlphaBltConstBitDepths( dword
                                                pAlphaBltConstBitDepths );      //added Set
    dword               __fastcall  FGetAlphaBltPixelBitDepths();
    void                __fastcall  FSetAlphaBltPixelBitDepths( dword
                                                pAlphaBltPixelBitDepths );      //added Set
    dword               __fastcall  FGetAlphaBltSurfaceBitDepths();
    void                __fastcall  FSetAlphaBltSurfaceBitDepths( dword
                                                pAlphaBltSurfaceBitDepths );    //added Set
    dword               __fastcall  FGetAlphaOverlayConstBitDepths();
    void                __fastcall  FSetAlphaOverlayConstBitDepths( dword
                                            pAlphaOverlayConstBitDepths );      //added Set
    dword               __fastcall  FGetAlphaOverlayPixelBitDepths();
    void                __fastcall  FSetAlphaOverlayPixelBitDepths( dword
                                            pAlphaOverlayPixelBitDepths );      //added Set
    dword               __fastcall  FGetAlphaOverlaySurfaceBitDepths();
    void                __fastcall  FSetAlphaOverlaySurfaceBitDepths( dword
                                            pAlphaOverlaySurfaceBitDepths );    //added Set
    dword               __fastcall  FGetZBufferBitDepths();
    void                __fastcall  FSetZBufferBitDepths( dword
                                                        pZBufferBitDepths );    //added Set
    dword               __fastcall  FGetVidMemTotal();
    void                __fastcall  FSetVidMemTotal( dword pVidMemTotal );      //added Set
    dword               __fastcall  FGetVidMemFree();
    void                __fastcall  FSetVidMemFree( dword pVidMemFree );        //added Set
    dword               __fastcall  FGetMaxVisibleOverlays();
    void                __fastcall  FSetMaxVisibleOverlays( dword
                                                    pMaxVisibleOverlays );      //added Set
    dword               __fastcall  FGetCurrVisibleOverlays();
    void                __fastcall  FSetCurrVisibleOverlays( dword
                                                    pCurrVisibleOverlays );     //added Set
    dword               __fastcall  FGetNumFourCCCodes();
    void                __fastcall  FSetNumFourCCCodes( dword
                                                        pNumFourCCCodes );      //added Set
    dword               __fastcall  FGetAlignBoundarySrc();
    void                __fastcall  FSetAlignBoundarySrc( dword
                                                        pAlignBoundarySrc );    //added Set
    dword               __fastcall  FGetAlignSizeSrc();
    void                __fastcall  FSetAlignSizeSrc( dword pAlignSizeSrc );    //added Set
    dword               __fastcall  FGetAlignBoundaryDest();
    void                __fastcall  FSetAlignBoundaryDest( dword
                                                    pAlignBoundaryDest );       //added Set
    dword               __fastcall  FGetAlignSizeDest();
    void                __fastcall  FSetAlignSizeDest( dword
                                                            pAlignSizeDest );   //added Set
    dword               __fastcall  FGetAlignStrideAlign();
    void                __fastcall  FSetAlignStrideAlign( dword
                                                        pAlignStrideAlign );    //added Set
    dword               __fastcall  FGetRops( int index );
//    void                __fastcall  FSetRops( dword pRops, int index );         //added Set
    dword               __fastcall  FGetSurfaceCaps();
    void                __fastcall  FSetSurfaceCaps( dword pSurfaceCaps );      //added Set
    dword               __fastcall  FGetMinOverlayStretch();
    void                __fastcall  FSetMinOverlayStretch( dword
                                                        pMinOverlayStretch );   //added Set
    dword               __fastcall  FGetMaxOverlayStretch();
    void                __fastcall  FSetMaxOverlayStretch( dword
                                                        pMaxOverlayStretch );   //added Set
    dword               __fastcall  FGetSVBCaps();
    void                __fastcall  FSetSVBCaps( dword pSVBCaps );              //added Set
    dword               __fastcall  FGetSVBCKeyCaps();
    void                __fastcall  FSetSVBCKeyCaps( dword pSVBCKeyCaps );      //added Set
    dword               __fastcall  FGetSVBFXCaps();
    void                __fastcall  FSetSVBFXCaps( dword pSVBFXCaps );          //added Set
    dword               __fastcall  FGetSVBRops( int index );
//    void                __fastcall  FSetSVBRops( dword pSVBRops, int index );   //added Set
    dword               __fastcall  FGetVSBCaps();
    void                __fastcall  FSetVSBCaps( dword pVSBCaps );              //added Set
    dword               __fastcall  FGetVSBCKeyCaps();
    void                __fastcall  FSetVSBCKeyCaps( dword pVSBCKeyCaps );      //added Set
    dword               __fastcall  FGetVSBFXCaps();
    void                __fastcall  FSetVSBFXCaps( dword pVSBFXCaps );          //added Set
    dword               __fastcall  FGetVSBRops( int index );
//    void                __fastcall  FSetVSBRops( dword pVSBRops, int index );   //added Set
    dword               __fastcall  FGetSSBCaps();
    void                __fastcall  FSetSSBCaps( dword pSSBCaps );              //added Set
    dword               __fastcall  FGetSSBCKeyCaps();
    void                __fastcall  FSetSSBCKeyCaps( dword pSSBCKeyCaps );      //added Set
    dword               __fastcall  FGetSSBFXCaps();
    void                __fastcall  FSetSSBFXCaps( dword pSSBFXCaps );          //added Set
    dword               __fastcall  FGetSSBRops( int index );
//    void                __fastcall  FSetSSBRops( dword pSSBRops, int index );   //added Set
    dword               __fastcall  FGetMaxVideoPorts();
    void                __fastcall  FSetMaxVideoPorts( dword
                                                            pMaxVideoPorts );   //added Set
    dword               __fastcall  FGetCurrVideoPorts();
    void                __fastcall  FSetCurrVideoPorts( dword
                                                        pCurrVideoPorts );      //added Set
    dword               __fastcall  FGetSVBCaps2();
    void                __fastcall  FSetSVBCaps2( dword pSVBCaps2 );            //added Set
    dword               __fastcall  FGetNLVBCaps();
    void                __fastcall  FSetNLVBCaps( dword pNLVBCaps );            //added Set
    dword               __fastcall  FGetNLVBCaps2();
    void                __fastcall  FSetNLVBCaps2( dword pNLVBCaps2 );          //added Set
    dword               __fastcall  FGetNLVBCKeyCaps();
    void                __fastcall  FSetNLVBCKeyCaps( dword pNLVBCKeyCaps );    //added Set
    dword               __fastcall  FGetNLVBFXCaps();
    void                __fastcall  FSetNLVBFXCaps( dword pNLVBFXCaps );        //added Set
    dword               __fastcall  FGetNLVBRops( int index );
//    void                __fastcall  FSetNLVBRops( dword pNLVBRops,
//                                                                int index );    //added Set

private:

    DDCAPS				fCaps;
};
//---------------------------------------------------------------------------
#endif
