//---------------------------------------------------------------------------
#ifndef TDDColorKeyH
#define TDDColorKeyH
// ==========================================================================
// File:            TDDColorKey.H
// Description:
//
// (c) 1998 A.S.C. Alternate Software Concepts, Sydney, Australia.
// All Rights Reserved. Refer to the file TDirectX_Licence.Txt for detailed
// licence & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
// include the basic TDirectDraw definitions, etc.
// --------------------------------------------------------------------------
#include "TDirectDrawInclude.h"
#include "TDirectDrawDefs.h"
#include "TDirectDrawErrors.h"

// ==========================================================================
// Class:           TDDColorKey
// Description:     This object describes a source color key, destination
//                  color key, or color space.
// Notes:           A color key is specified if the low and high range values
//                  are the same.
//                  This object is used with the
//                  TDirectDrawSurface::GetColorKey and
//                  TDirectDrawSurface::SetColorKey methods
// ==========================================================================
class TDDColorKey : public TPersistent
{
__published:
public:

// --------------------------------------------------------------------------
// Property:        LowValue
// Description:     The low value, inclusive, of the color range that is to
//                  be used as the color key
// --------------------------------------------------------------------------
    __property      dword                  LowValue = { read=FGetLowValue,
                                                        write=FSetLowValue,
                                                        default=clBlack };

    //
// --------------------------------------------------------------------------
// Property:        HighValue
// Description:     The high value, inclusive, of the color range that is to
//                  be used as the color key
// --------------------------------------------------------------------------
    __property      dword                 HighValue = { read=FGetHighValue,
                                                        write=FSetHighValue,
                                                        default=clBlack };

// --------------------------------------------------------------------------
// Method:        Size
// Description:     This returns the size of the internal DDCOLORKEY
//                  structure.
// --------------------------------------------------------------------------
    dword   __fastcall      Size();

// --------------------------------------------------------------------------
// Method:          Ptr
// Description:     This property returns a pointer to the internal
//                  DDCOLORKEY structure.
// --------------------------------------------------------------------------
    DDCOLORKEY*     __fastcall      Ptr();

// --------------------------------------------------------------------------
// Constructor & Destructor
// --------------------------------------------------------------------------
                    __fastcall      TDDColorKey();
    virtual         __fastcall      ~TDDColorKey();

// --------------------------------------------------------------------------
// End of the TDDColorKey wrapper
// --------------------------------------------------------------------------

protected:

    dword           __fastcall      FGetLowValue();
    void            __fastcall      FSetLowValue( dword lowvalue );
    dword           __fastcall      FGetHighValue();
    void            __fastcall      FSetHighValue( dword highvalue );

private:

    DDCOLORKEY      fColorKey;
};
//---------------------------------------------------------------------------
#endif
