// --------------------------------------------------------------------------
#include <vcl\vcl.h>
#pragma hdrstop

// ==========================================================================
// File:            TDDSurfaceDesc.CPP
// Description:
//
// (c) 1998 A.S.C. Alternate Software Concepts, Sydney, Australia.
// All Rights Reserved. Refer to the file TDirectX_Licence.Txt for detailed
// licence & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
// include the TDDSurfaceDesc H file.
// --------------------------------------------------------------------------
#include "TDDSurfaceDesc.h"

// ==========================================================================
// Class:           TDDSurfaceDesc
// Description:     This object contains a description of the surface to be
//                  created. This object is passed to the
//                  TDirectDraw::CreateSurface method. The relevant members
//                  differ for each potential type of surface.
// ==========================================================================

// --------------------------------------------------------------------------
// Constructor
// --------------------------------------------------------------------------
                    __fastcall  TDDSurfaceDesc::TDDSurfaceDesc()
                                                            : TPersistent()
{
fSurfaceDesc.dwSize = sizeof(DDSURFACEDESC);
fSurfaceDesc.ddsCaps.dwCaps = 0;
fSCaps = new TDDSCaps();
fCKDestOverlay = new TDDColorKey();
fCKDestBlt = new TDDColorKey();
fCKSrcOverlay = new TDDColorKey();
fCKSrcBlt = new TDDColorKey();
fPixelFormat = new TDDPixelFormat();
}

// --------------------------------------------------------------------------
// Destructor
// --------------------------------------------------------------------------
                    __fastcall  TDDSurfaceDesc::~TDDSurfaceDesc()
{
delete fPixelFormat;
delete fCKSrcBlt;
delete fCKSrcOverlay;
delete fCKDestBlt;
delete fCKDestOverlay;
delete fSCaps;
}

// --------------------------------------------------------------------------
// Method:          Size
// Description:     This returns the size of the internal DDSURFACEDESC
//                  structure.
// --------------------------------------------------------------------------
dword               __fastcall  TDDSurfaceDesc::Size()
{
return sizeof(DDSURFACEDESC);
}

// --------------------------------------------------------------------------
// Method:          Ptr
// Description:     This method returns a pointer to the internal
//                  DDSURFACEDESC structure.
// --------------------------------------------------------------------------
DDSURFACEDESC*      __fastcall  TDDSurfaceDesc::Ptr()
{
return &fSurfaceDesc;
}

// --------------------------------------------------------------------------
// Method:          FGetFlags
// Description:     Returns optional control flags.
// Note:            One or more of TDDSurfaceFlags
// --------------------------------------------------------------------------
dword               __fastcall  TDDSurfaceDesc::FGetFlags()
{
return fSurfaceDesc.dwFlags;
}

// --------------------------------------------------------------------------
// Method:          FSetFlags
// Description:     Sets optional control flags.
// Note:            One or more of TDDSurfaceFlags
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetFlags( dword pFlags )
{
fSurfaceDesc.dwFlags = pFlags;
}

// --------------------------------------------------------------------------
// Method:          FGetHeight
// Description:     Returns the height of the surface to be created, in
//                  pixels
// --------------------------------------------------------------------------
dword               __fastcall  TDDSurfaceDesc::FGetHeight()
{
return fSurfaceDesc.dwHeight;
}

// --------------------------------------------------------------------------
// Method:          FSetHeight
// Description:     Sets the height of the surface to be created, in pixels
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetHeight( dword pHeight )
{
fSurfaceDesc.dwHeight = pHeight;
}

// --------------------------------------------------------------------------
// Method:          FGetWidth
// Description:     Returns the width of the surface to be created, in pixels
// --------------------------------------------------------------------------
dword               __fastcall  TDDSurfaceDesc::FGetWidth()
{
return fSurfaceDesc.dwWidth;
}

// --------------------------------------------------------------------------
// Method:          FSetWidth
// Description:     Set the width of the surface to be created, in pixels
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetWidth( dword pWidth )
{
fSurfaceDesc.dwWidth = pWidth;
}

// --------------------------------------------------------------------------
// Method:          FGetPitch
// Description:     Returns the distance, in bytes, to the start of next line
// Note:            When used with the TDirectDrawSurface::GetSurfaceDesc
//                  method, this is a return value.
// --------------------------------------------------------------------------
long                __fastcall  TDDSurfaceDesc::FGetPitch()
{
return fSurfaceDesc.lPitch;
}

// --------------------------------------------------------------------------
// Method:          FSetPitch
// Description:     Sets the distance, in bytes, to the start of next line.
// Note:            When used with the TDirectDrawSurface::SetSurfaceDesc
//                  method, this is an input value that must be a dword
//                  multiple
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetPitch( long pPitch )
{
fSurfaceDesc.lPitch = pPitch;
}

// --------------------------------------------------------------------------
// Method:          FGetBackBufferCount
// Description:     Returns the number of Back Buffers
// --------------------------------------------------------------------------
dword               __fastcall  TDDSurfaceDesc::FGetBackBufferCount()
{
return fSurfaceDesc.dwBackBufferCount;
}

// --------------------------------------------------------------------------
// Method:          FSetBackBufferCount
// Description:     Sets the number of Back Buffers
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetBackBufferCount( dword
                                                        pBackBufferCount )
{
fSurfaceDesc.dwBackBufferCount = pBackBufferCount;
}

// --------------------------------------------------------------------------
// Method:          FGetMipMapCount
// Description:     Returns the number of MipMap levels
// --------------------------------------------------------------------------
dword               __fastcall  TDDSurfaceDesc::FGetMipMapCount()
{
return fSurfaceDesc.dwMipMapCount;
}

// --------------------------------------------------------------------------
// Method:          FSetMipMapCount
// Description:     Sets the number of MipMap levels
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetMipMapCount( dword
                                                            pMipMapCount )
{
fSurfaceDesc.dwMipMapCount = pMipMapCount;
}

// --------------------------------------------------------------------------
// Method:          FGetZBufferBitDepth
// Description:     Returns the depth of the z-buffer.
// Note:            32-bit z-buffers are not supported
// --------------------------------------------------------------------------
dword               __fastcall  TDDSurfaceDesc::FGetZBufferBitDepth()
{
return fSurfaceDesc.dwZBufferBitDepth;
}

// --------------------------------------------------------------------------
// Method:          FSetZBufferBitDepth
// Description:     Sets the depth of the z-buffer.
// Note:            32-bit z-buffers are not supported
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetZBufferBitDepth( dword
                                                        pZBufferBitDepth )
{
fSurfaceDesc.dwZBufferBitDepth = pZBufferBitDepth;
}

// --------------------------------------------------------------------------
// Method:          FGetRefreshRate
// Description:     Returns the refresh rate
// Note:            Used when the display mode is described
//                  A value of 0 indicates an adapter fault
// --------------------------------------------------------------------------
dword               __fastcall  TDDSurfaceDesc::FGetRefreshRate()
{
return fSurfaceDesc.dwRefreshRate;
}

// --------------------------------------------------------------------------
// Method:          FSetRefreshRate
// Description:     Sets the refresh rate
// Note:            Used when the display mode is described
//                  A value of 0 indicates an adapter fault
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetRefreshRate( dword
                                                            pRefreshRate )
{
fSurfaceDesc.dwZBufferBitDepth = pRefreshRate;
}

// --------------------------------------------------------------------------
// Method:          FGetAlphaBitDepth
// Description:     Returns the depth of the alpha buffer
// --------------------------------------------------------------------------
dword               __fastcall  TDDSurfaceDesc::FGetAlphaBitDepth()
{
return fSurfaceDesc.dwAlphaBitDepth;
}

// --------------------------------------------------------------------------
// Method:          FSetAlphaBitDepth
// Description:     Sets the depth of the alpha buffer
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetAlphaBitDepth( dword
                                                            pAlphaBitDepth )
{
fSurfaceDesc.dwAlphaBitDepth = pAlphaBitDepth;
}

// --------------------------------------------------------------------------
// Method:          FGetCKDestOverlay
// Description:     Returns the TDDColorKey object that describes the
//                  destination color key to be used for an overlay surface
// --------------------------------------------------------------------------
TDDColorKey*        __fastcall  TDDSurfaceDesc::FGetCKDestOverlay()
{
return fCKDestOverlay;
}

// --------------------------------------------------------------------------
// Method:          FSetCKDestOverlay
// Description:     Sets the TDDColorKey object that describes the
//                  destination color key to be used for an overlay surface
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetCKDestOverlay(
                                                TDDColorKey* pCKDestOverlay )
{
if (pCKDestOverlay!=NULL)
    {
    fCKDestOverlay->LowValue = pCKDestOverlay->LowValue;
    fCKDestOverlay->HighValue = pCKDestOverlay->HighValue;
    }
}

// --------------------------------------------------------------------------
// Method:          FGetCKDestBlt
// Description:     Returns the TDDColorKey object that describes the
//                  destination color key for blit operations
// --------------------------------------------------------------------------
TDDColorKey*        __fastcall  TDDSurfaceDesc::FGetCKDestBlt()
{
return fCKDestBlt;
}

// --------------------------------------------------------------------------
// Method:          FSetCKDestBlt
// Description:     Sets the TDDColorKey object that describes the
//                  destination color key for blit operations
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetCKDestBlt( TDDColorKey*
                                                                pCKDestBlt )
{
if (pCKDestBlt!=NULL)
    {
    fCKDestBlt->LowValue = pCKDestBlt->LowValue;
    fCKDestBlt->HighValue = pCKDestBlt->HighValue;
    }
}

// --------------------------------------------------------------------------
// Method:          FGetCKSrcOverlay
// Description:     Returns the TDDColorKey object that describes the source
//                  color key to be used for an overlay surface
// --------------------------------------------------------------------------
TDDColorKey*        __fastcall  TDDSurfaceDesc::FGetCKSrcOverlay()
{
return fCKSrcOverlay;
}

// --------------------------------------------------------------------------
// Method:          FSetCKSrcOverlay
// Description:     Sets the TDDColorKey object that describes the source
//                  color key to be used for an overlay surface
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetCKSrcOverlay(
                                                TDDColorKey* pCKSrcOverlay )
{
if (pCKSrcOverlay!=NULL)
    {
    fCKSrcOverlay->LowValue = pCKSrcOverlay->LowValue;
    fCKSrcOverlay->HighValue = pCKSrcOverlay->HighValue;
    }
}

// --------------------------------------------------------------------------
// Method:          FGetCKSrcBlt
// Description:     Returns the TDDColorKey object that describes the source
//                  color key for blit operations
// --------------------------------------------------------------------------
TDDColorKey*        __fastcall  TDDSurfaceDesc::FGetCKSrcBlt()
{
return fCKSrcBlt;
}

// --------------------------------------------------------------------------
// Method:          FSetCKSrcBlt
// Description:     Sets the TDDColorKey object that describes the source
//                  color key for blit operations
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetCKSrcBlt( TDDColorKey*
                                                                pCKSrcBlt )
{
if (pCKSrcBlt!=NULL)
    {
    fCKSrcBlt->LowValue = pCKSrcBlt->LowValue;
    fCKSrcBlt->HighValue = pCKSrcBlt->HighValue;
    }
}

// --------------------------------------------------------------------------
// Method:          FGetPixelFormat
// Description:     Returns the TDDPixelFormat object that describes the
//                  surface's pixel format
// --------------------------------------------------------------------------
TDDPixelFormat*     __fastcall  TDDSurfaceDesc::FGetPixelFormat()
{
return fPixelFormat;
}

// --------------------------------------------------------------------------
// Method:          FSetPixelFormat
// Description:     Sets the TDDPixelFormat object that describes the
//                  surface's pixel format
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetPixelFormat(
                                            TDDPixelFormat* pPixelFormat )
{
if (pPixelFormat!=NULL)
    {
//    fPixelFormat->LowValue = pPixelFormat->LowValue;
//    fPixelFormat->HighValue = pPixelFormat->HighValue;
    }
}

// --------------------------------------------------------------------------
// Method:          FGetSCaps
// Description:     Returns the TDDSCaps object containing the surface's
//                  capabilities
// --------------------------------------------------------------------------
TDDSCaps*           __fastcall  TDDSurfaceDesc::FGetSCaps()
{
return fSCaps;
}

// --------------------------------------------------------------------------
// Method:          FSetSCaps
// Description:     Sets the TDDSCaps object containing the surface's
//                  capabilities
// --------------------------------------------------------------------------
void                __fastcall  TDDSurfaceDesc::FSetSCaps( TDDSCaps* pSCaps )
{
if (pSCaps!=NULL)
    {
    fSCaps->Caps = pSCaps->Caps;
    fSurfaceDesc.ddsCaps.dwCaps = fSCaps->Caps;
    }
}

// --------------------------------------------------------------------------
// Method:          Surface
// Description:     Address of the associated surface memory.
// Note:            When calling TDirectDrawSurface::Lock, this member is a
//                  valid pointer to surface memory. When calling
//                  TDirectDrawSurface::SetSurfaceDesc, this member is a
//                  pointer to system memory that the caller explicitly
//                  allocates for the TDirectDrawSurface object
// --------------------------------------------------------------------------
void*               __fastcall  TDDSurfaceDesc::Surface()
{
return fSurfaceDesc.lpSurface;
}
//---------------------------------------------------------------------------

