//---------------------------------------------------------------------------
#ifndef TDDSurfaceDescH
#define TDDSurfaceDescH

// ==========================================================================
// File:            TDDSurfaceDesc.H
// Description:
//
// (c) 1998 A.S.C. Alternate Software Concepts, Sydney, Australia.
// All Rights Reserved. Refer to the file TDirectX_Licence.Txt for detailed
// licence & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
// include the basic TDirectDraw definitions, etc.
// --------------------------------------------------------------------------
#include "TDirectDrawInclude.h"
#include "TDirectDrawDefs.h"
#include "TDirectDrawErrors.h"
#include "TDirectDrawMisc.h"

// --------------------------------------------------------------------------
// include the various DirectX Wrapper classes used by TDDSurfaceDesc
// --------------------------------------------------------------------------
#include "TDDSCaps.h"
#include "TDDColorKey.h"
#include "TDDPixelFormat.h"

// ==========================================================================
// Class:           TDDSurfaceDesc
// Description:     This object contains a description of the surface to be
//                  created. This object is passed to the
//                  TDirectDraw::CreateSurface method. The relevant members
//                  differ for each potential type of surface
// ==========================================================================
class TDDSurfaceDesc : public TPersistent
{
__published:
public:

// --------------------------------------------------------------------------
// Property:        Flags
// Description:     Optional control flags. One or more of TDDSurfaceFlags
// --------------------------------------------------------------------------
    __property      dword                     Flags = { read=FGetFlags,
                                                        write=FSetFlags,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        Height
// Description:     Height of the surface to be created, in pixels
// --------------------------------------------------------------------------
    __property      dword                    Height = { read=FGetHeight,
                                                        write=FSetHeight,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        Width
// Description:     Width of the surface to be created, in pixels
// --------------------------------------------------------------------------
    __property      dword                     Width = { read=FGetWidth,
                                                        write=FSetWidth,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        Pitch
// Description:     Distance, in bytes, to the start of next line.
// Note:            When used with the TDirectDrawSurface::GetSurfaceDesc
//                  method, this is a return value. When used with the
//                  TDirectDrawSurface::SetSurfaceDesc method, this is an
//                  input value that must be a dword multiple
// --------------------------------------------------------------------------
    __property      long                      Pitch = { read=FGetPitch,
                                                        write=FSetPitch,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        BackBufferCount
// Description:     Number of Back Buffers
// --------------------------------------------------------------------------
    __property      dword           BackBufferCount = {
                                                    read=FGetBackBufferCount,
                                                    write=FSetBackBufferCount
                                                    ,nodefault };

// --------------------------------------------------------------------------
// Property:        MipMapCount
// Description:     Number of MipMap levels
// --------------------------------------------------------------------------
    __property      dword               MipMapCount = { read=FGetMipMapCount,
                                                        write=FSetMipMapCount
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        ZBufferBitDepth
// Description:     Depth of the z-buffer.
// Note:            32-bit z-buffers are not supported
// --------------------------------------------------------------------------
    __property      dword           ZBufferBitDepth = {
                                                    read=FGetZBufferBitDepth,
                                                    write=FSetZBufferBitDepth
                                                    ,nodefault };

// --------------------------------------------------------------------------
// Property:        RefreshRate
// Description:     Refresh rate
// Note:            Used when the display mode is described
//                  A value of 0 indicates an adapter fault
// --------------------------------------------------------------------------
    __property      dword               RefreshRate = { read=FGetRefreshRate,
                                                        write=FSetRefreshRate
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        AlphaBitDepth
// Description:     Depth of the alpha buffer
// --------------------------------------------------------------------------
    __property      dword             AlphaBitDepth = {
                                                    read=FGetAlphaBitDepth,
                                                    write=FSetAlphaBitDepth,
                                                    nodefault };

// --------------------------------------------------------------------------
// Property:        CKDestOverlay
// Description:     TDDColorKey object that describes the destination color
//                  key to be used for an overlay surface
// --------------------------------------------------------------------------
    //
    __property      TDDColorKey*      CKDestOverlay = {
                                                    read=FGetCKDestOverlay,
                                                    write=FSetCKDestOverlay,
                                                    nodefault };

// --------------------------------------------------------------------------
// Property:        CKDestBlt
// Description:     TDDColorKey object that describes the destination color
//                  key for blit operations
// --------------------------------------------------------------------------
    __property      TDDColorKey*          CKDestBlt = { read=FGetCKDestBlt,
                                                        write=FSetCKDestBlt,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        CKSrcOverlay
// Description:     TDDColorKey object that describes the source color key to
//                  be used for an overlay surface
// --------------------------------------------------------------------------
    __property      TDDColorKey*       CKSrcOverlay = {
                                                    read=FGetCKSrcOverlay,
                                                    write=FSetCKSrcOverlay,
                                                    nodefault };

// --------------------------------------------------------------------------
// Property:        CKSrcBlt
// Description:     TDDColorKey object that describes the source color key
//                  for blit operations
// --------------------------------------------------------------------------
    //
    __property      TDDColorKey*           CKSrcBlt = { read=FGetCKSrcBlt,
                                                        write=FSetCKSrcBlt,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        PixelFormat
// Description:     TDDPixelFormat object that describes the surface's pixel
//                  format
// --------------------------------------------------------------------------
    __property      TDDPixelFormat*     PixelFormat = { read=FGetPixelFormat,
                                                        write=FSetPixelFormat
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        SCaps
// Description:     TDDSCaps object containing the surface's capabilities
// --------------------------------------------------------------------------
    __property      TDDSCaps*                 SCaps = { read=FGetSCaps,
                                                        write=FSetSCaps,
                                                        nodefault };

// --------------------------------------------------------------------------
// Method:          Surface
// Description:     Address of the associated surface memory.
// Note:            When calling TDirectDrawSurface::Lock, this member is a
//                  valid pointer to surface memory. When calling
//                  TDirectDrawSurface::SetSurfaceDesc, this member is a
//                  pointer to system memory that the caller explicitly
//                  allocates for the TDirectDrawSurface object
// --------------------------------------------------------------------------
    void*               __fastcall  Surface();

// --------------------------------------------------------------------------
// Method:          Size
// Description:     This returns the size of the internal DDSURFACEDESC
//                  structure.
// --------------------------------------------------------------------------
    dword               __fastcall  Size();

// --------------------------------------------------------------------------
// Method:          Ptr
// Description:     This property returns a pointer to the internal
//                  DDSURFACEDESC structure.
// --------------------------------------------------------------------------
   DDSURFACEDESC*       __fastcall  Ptr();

// --------------------------------------------------------------------------
// Constructor & Destructor
// --------------------------------------------------------------------------
                        __fastcall  TDDSurfaceDesc();
    virtual             __fastcall  ~TDDSurfaceDesc();

// --------------------------------------------------------------------------
// End of the TDDBltBatch wrapper
// --------------------------------------------------------------------------

protected:

    dword               __fastcall  FGetFlags();
    void                __fastcall  FSetFlags( dword pFlags );
    dword               __fastcall  FGetHeight();
    void                __fastcall  FSetHeight( dword pHeight );
    dword               __fastcall  FGetWidth();
    void                __fastcall  FSetWidth( dword pWidth );
    long                __fastcall  FGetPitch();
    void                __fastcall  FSetPitch( long pPitch );
    dword               __fastcall  FGetBackBufferCount();
    void                __fastcall  FSetBackBufferCount( dword
                                                        pBackBufferCount );
    dword               __fastcall  FGetMipMapCount();
    void                __fastcall  FSetMipMapCount( dword pMipMapCount );
    dword               __fastcall  FGetZBufferBitDepth();
    void                __fastcall  FSetZBufferBitDepth( dword
                                                        pZBufferBitDepth );
    dword               __fastcall  FGetRefreshRate();
    void                __fastcall  FSetRefreshRate( dword pRefreshRate );
    dword               __fastcall  FGetAlphaBitDepth();
    void                __fastcall  FSetAlphaBitDepth( dword
                                                            pAlphaBitDepth );
    TDDColorKey*        __fastcall  FGetCKDestOverlay();
    void                __fastcall  FSetCKDestOverlay( TDDColorKey*
                                                            pCKDestOverlay );
    TDDColorKey*        __fastcall  FGetCKDestBlt();
    void                __fastcall  FSetCKDestBlt( TDDColorKey* pCKDestBlt );
    TDDColorKey*        __fastcall  FGetCKSrcOverlay();
    void                __fastcall  FSetCKSrcOverlay( TDDColorKey*
                                                            pCKSrcOverlay );
    TDDColorKey*        __fastcall  FGetCKSrcBlt();
    void                __fastcall  FSetCKSrcBlt( TDDColorKey* pCKSrcBlt );
    TDDPixelFormat*     __fastcall  FGetPixelFormat();
    void                __fastcall  FSetPixelFormat( TDDPixelFormat*
                                                            pPixelFormat );
    TDDSCaps*           __fastcall  FGetSCaps();
    void                __fastcall  FSetSCaps( TDDSCaps* pSCaps );

private:

    DDSURFACEDESC       fSurfaceDesc;
    TDDSCaps*           fSCaps;
    TDDColorKey*        fCKDestOverlay;
    TDDColorKey*        fCKDestBlt;
    TDDColorKey*        fCKSrcOverlay;
    TDDColorKey*        fCKSrcBlt;
    TDDPixelFormat*     fPixelFormat;

};
//---------------------------------------------------------------------------
#endif
