// --------------------------------------------------------------------------
#ifndef TDDVideoPortConnectH
#define TDDVideoPortConnectH

// ==========================================================================
// File:            TDDVideoPortConnect.H
// Description:
//
// (c) 1998 A.S.C. Alternate Software Concepts, Sydney, Australia.
// All Rights Reserved. Refer to the file TDirectX_Licence.Txt for detailed
// licence & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
// include the basic TDirectDraw definitions, etc.
// --------------------------------------------------------------------------
#include "TDirectDrawInclude.h"
#include "TDirectDrawDefs.h"
#include "TDirectDrawErrors.h"

// ==========================================================================
// Class:           TDDVideoPortConnect
// Description:     The TDDVideoPortConnect object describes a video port
//                  connection
// Note:            This object is used with the
//                  TDirectDrawVideoPortContainer::GetVideoPortConnectInfo
//                  method
// ==========================================================================
class TDDVideoPortConnect : public TPersistent
{
__published:
public:

// --------------------------------------------------------------------------
// Property:        PortWidth
// Description:     Width of the video port
// Note:            This value represents the number of physical pins on the
//                  video port, not the width of a surface in memory. This
//                  member must always be set, even when the value in the
//                  TypeID property assumes a certain size
// --------------------------------------------------------------------------
    __property      dword                 PortWidth = { read=FGetPortWidth,
                                                        write=FSetPortWidth,    //added write, nodefault
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        TypeID
// Description:     A TDDVideoPortConnectGUID that describes the sync
//                  characteristics of the video port
// --------------------------------------------------------------------------
    __property      GUID                     TypeID = { read=FGetTypeID,
                                                        write=FSetTypeID,      //added write, nodefault
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        Flags
// Description:     Flags describing the capabilities of the video-port
//                  connection
// Note:            This member can be set by DirectDraw when connection
//                  information is being retrieved or by the client when
//                  connection information is being set.
// --------------------------------------------------------------------------
    __property      dword                     Flags = { read=FGetFlags,
                                                        write=FSetFlags,
                                                        nodefault };



// --------------------------------------------------------------------------
// Method:          Size
// Description:     This returns the size of the internal DDVIDEOPORTCONNECT
//                  structure
// --------------------------------------------------------------------------
    dword           __fastcall  Size();

// --------------------------------------------------------------------------
// Method:          Ptr
// Description:     This property returns a pointer to the internal
//                  DDVIDEOPORTCONNECT structure.
// --------------------------------------------------------------------------
DDVIDEOPORTCONNECT* __fastcall  Ptr();

// --------------------------------------------------------------------------
// Constructor & Destructor
// --------------------------------------------------------------------------
                    __fastcall  TDDVideoPortConnect();
    virtual         __fastcall  ~TDDVideoPortConnect();

// --------------------------------------------------------------------------
// End of the TDDBltBatch wrapper
// --------------------------------------------------------------------------

protected:

    dword           __fastcall  FGetPortWidth();
    void            __fastcall  FSetPortWidth( dword pPortWidth );              //added set
    GUID            __fastcall  FGetTypeID();
    void            __fastcall  FSetTypeID( GUID pTypeID );                     //added set
    dword           __fastcall  FGetFlags();
    void            __fastcall  FSetFlags( dword pFlags );                      //added set

private:

    DDVIDEOPORTCONNECT  fVideoPortConnect;
};
//---------------------------------------------------------------------------
#endif
