// --------------------------------------------------------------------------
#include <vcl\vcl.h>
#pragma hdrstop

// ==========================================================================
// File:            TDDVideoPortDesc.CPP
// Description:
//
// (c) 1998 A.S.C. Alternate Software Concepts, Sydney, Australia.
// All Rights Reserved. Refer to the file TDirectX_Licence.Txt for detailed
// licence & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
// include the TDDVideoPortDesc H file.
// --------------------------------------------------------------------------
#include "TDDVideoPortDesc.h"

// ==========================================================================
// Class:           TDDVideoPortDesc
// Description:     This object describes a video-port object to be created
// Note:            This object is used with the
//                  TDirectDrawVideoPortContainer::CreateVideoPort method
// ==========================================================================

// --------------------------------------------------------------------------
// Constructor
// --------------------------------------------------------------------------
                    __fastcall  TDDVideoPortDesc::TDDVideoPortDesc()
                                                            : TPersistent()
{
fVideoPortDesc.dwSize = sizeof(DDVIDEOPORTDESC);
}

// --------------------------------------------------------------------------
// Destructor
// --------------------------------------------------------------------------
__fastcall  TDDVideoPortDesc::~TDDVideoPortDesc()
{
}

// --------------------------------------------------------------------------
// Method:          Size
// Description:     This returns the size of the internal DDVIDEOPORTDESC
//                  structure
// --------------------------------------------------------------------------
dword       __fastcall  TDDVideoPortDesc::Size()
{
return sizeof(DDVIDEOPORTDESC);
}

// --------------------------------------------------------------------------
// Method:          Ptr
// Description:     This returns a pointer to the internal
//                  DDVIDEOPORTDESC structure
// --------------------------------------------------------------------------
DDVIDEOPORTDESC*    __fastcall  TDDVideoPortDesc::Ptr()
{
return &fVideoPortDesc;
}

// --------------------------------------------------------------------------
// Method:          FGetFieldWidth
// Description:     Returns the width of incoming video stream, in pixels
// --------------------------------------------------------------------------
dword               __fastcall  TDDVideoPortDesc::FGetFieldWidth()
{
return fVideoPortDesc.dwFieldWidth;
}

// --------------------------------------------------------------------------
// Method:          FSetFieldWidth
// Description:     Sets the width of incoming video stream, in pixels
// --------------------------------------------------------------------------
void                __fastcall  TDDVideoPortDesc::FSetFieldWidth( dword
                                                                fieldwidth )
{
fVideoPortDesc.dwFieldWidth = fieldwidth;
}

// --------------------------------------------------------------------------
// Method:          FGetVBIWidth
// Description:     Returns the width of the VBI data in the incoming video
//                  stream, in pixels
// --------------------------------------------------------------------------
dword               __fastcall  TDDVideoPortDesc::FGetVBIWidth()
{
return fVideoPortDesc.dwVBIWidth;
}

// --------------------------------------------------------------------------
// Method:          FSetVBIWidth
// Description:     Sets the width of the VBI data in the incoming video
//                  stream, in pixels
// --------------------------------------------------------------------------
void                __fastcall  TDDVideoPortDesc::FSetVBIWidth( dword
                                                                vbiwidth )
{
fVideoPortDesc.dwVBIWidth = vbiwidth;
}

// --------------------------------------------------------------------------
// Method:          FGetFieldHeight
// Description:     Returns the field height for fields in the incoming video
//                  stream, in scan lines
// --------------------------------------------------------------------------
dword       __fastcall  TDDVideoPortDesc::FGetFieldHeight()
{
return fVideoPortDesc.dwFieldHeight;
}

// --------------------------------------------------------------------------
// Method:          FSetFieldHeight
// Description:     Sets the field height for fields in the incoming video
//                  stream, in scan lines
// --------------------------------------------------------------------------
void                __fastcall  TDDVideoPortDesc::FSetFieldHeight( dword
                                                                fieldheight )
{
fVideoPortDesc.dwFieldHeight = fieldheight;
}

// --------------------------------------------------------------------------
// Method:          FGetMicrosecondsPerField
// Description:     Returns the time interval, in microseconds, between live
//                  video VREF periods
// --------------------------------------------------------------------------
dword       __fastcall  TDDVideoPortDesc::FGetMicrosecondsPerField()
{
return fVideoPortDesc.dwMicrosecondsPerField;
}

// --------------------------------------------------------------------------
// Method:          FSetMicrosecondsPerField
// Description:     Sets the time interval, in microseconds, between live
//                  video VREF periods
// Note:            This number should be rounded up to the nearest
//                  microsecond
// --------------------------------------------------------------------------
void                __fastcall  TDDVideoPortDesc::FSetMicrosecondsPerField(
                                                dword microsecondsperfield )
{
fVideoPortDesc.dwMicrosecondsPerField = microsecondsperfield;
}

// --------------------------------------------------------------------------
// Method:          FGetVideoPortID
// Description:     Returns the zero-based ID of the physical video port to
//                  be used
// --------------------------------------------------------------------------
dword               __fastcall  TDDVideoPortDesc::FGetVideoPortID()
{
return fVideoPortDesc.dwVideoPortID;
}

// --------------------------------------------------------------------------
// Method:          FSetVideoPortID
// Description:     Sets the zero-based ID of the physical video port to be
//                  used
// --------------------------------------------------------------------------
void                __fastcall  TDDVideoPortDesc::FSetVideoPortID( dword
                                                                videoportid )
{
fVideoPortDesc.dwVideoPortID = videoportid;
}

// --------------------------------------------------------------------------
// Method:          FGetVideoPortType
// Description:     Returns a TDDVideoPortConnect object describing the
//                  connection characteristics of the video port
// --------------------------------------------------------------------------
TDDVideoPortConnect* __fastcall TDDVideoPortDesc::FGetVideoPortType()

{
return NULL;
}

// --------------------------------------------------------------------------
// Method:          FSetVideoPortType
// Description:     Sets a TDDVideoPortConnect object describing the
//                  connection characteristics of the video port
// --------------------------------------------------------------------------
void                __fastcall  TDDVideoPortDesc::FSetVideoPortType
                                    (TDDVideoPortConnect* videoportconnect )
{
if (videoportconnect!=NULL) CopyMemory( &fVideoPortDesc.VideoPortType,
                        videoportconnect->Ptr(), videoportconnect->Size() );
}

// --------------------------------------------------------------------------

