// --------------------------------------------------------------------------
#ifndef TDDVideoPortDescH
#define TDDVideoPortDescH

// ==========================================================================
// File:            TDDVideoPortDesc.H
// Description:
//
// (c) 1998 A.S.C. Alternate Software Concepts, Sydney, Australia.
// All Rights Reserved. Refer to the file TDirectX_Licence.Txt for detailed
// licence & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
// include the basic TDirectDraw definitions, etc.
// --------------------------------------------------------------------------
#include "TDirectDrawInclude.h"
#include "TDirectDrawDefs.h"
#include "TDirectDrawErrors.h"

// --------------------------------------------------------------------------
// include the various DirectX Wrapper classes used by TDDVideoPortDesc
// --------------------------------------------------------------------------
#include "TDDVideoPortConnect.h"

// ==========================================================================
// Class:           TDDVideoPortDesc
// Description:     This object describes a video-port object to be created
// Note:            This object is used with the
//                  TDirectDrawVideoPortContainer::CreateVideoPort method
// ==========================================================================
class TDDVideoPortDesc : public TPersistent
{
__published:
public:

// --------------------------------------------------------------------------
// Property:        FieldWidth
// Description:     Width of incoming video stream, in pixels
// --------------------------------------------------------------------------
    __property      dword                FieldWidth = { read=FGetFieldWidth,
                                                        write=FSetFieldWidth,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        VBIWidth
// Description:     Width of the VBI data in the incoming video stream, in
//                  pixels
// --------------------------------------------------------------------------
    __property      dword                  VBIWidth = { read=FGetVBIWidth,
                                                        write=FSetVBIWidth,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        FieldHeight
// Description:     Field height for fields in the incoming video stream, in
//                  scan lines
// --------------------------------------------------------------------------
    __property      dword               FieldHeight = { read=FGetFieldHeight,
                                                        write=FSetFieldHeight
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        MicrosecondsPerField
// Description:     Time interval, in microseconds, between live video VREF
//                  periods
// Note:            This number should be rounded up to the nearest
//                  microsecond
// --------------------------------------------------------------------------
    __property      dword      MicrosecondsPerField = {
                                            read=FGetMicrosecondsPerField,
                                            write=FSetMicrosecondsPerField,
                                            nodefault };

// --------------------------------------------------------------------------
// Property:        VideoPortID
// Description:     The zero-based ID of the physical video port to be used
// --------------------------------------------------------------------------
    __property      dword               VideoPortID = { read=FGetVideoPortID,
                                                        write=FSetVideoPortID
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        VideoPortType
// Description:     A TDDVideoPortConnect object describing the connection
//                  characteristics of the video port
// --------------------------------------------------------------------------
    __property   TDDVideoPortConnect* VideoPortType = {
                                                    read=FGetVideoPortType,     //added read
                                                    write=FSetVideoPortType,
                                                    nodefault };

// --------------------------------------------------------------------------
// Method:          Size
// Description:     This returns the size of the internal DDVIDEOPORTDESC
//                  structure
// --------------------------------------------------------------------------
    dword       __fastcall  Size();

// --------------------------------------------------------------------------
// Method:          Ptr
// Description:     This returns a pointer to the internal
//                  DDVIDEOPORTDESC structure
// --------------------------------------------------------------------------
DDVIDEOPORTDESC* __fastcall  Ptr();

// --------------------------------------------------------------------------
// Constructor & Destructor
// --------------------------------------------------------------------------
                __fastcall  TDDVideoPortDesc();
    virtual     __fastcall  ~TDDVideoPortDesc();

// --------------------------------------------------------------------------
// End of the TDDBltBatch wrapper
// --------------------------------------------------------------------------

protected:

    dword       __fastcall  FGetFieldWidth();
    void        __fastcall  FSetFieldWidth( dword fieldwidth );
    dword       __fastcall  FGetVBIWidth();
    void        __fastcall  FSetVBIWidth( dword vbiwidth );
    dword       __fastcall  FGetFieldHeight();
    void        __fastcall  FSetFieldHeight( dword fieldheight );
    dword       __fastcall  FGetMicrosecondsPerField();
    void        __fastcall  FSetMicrosecondsPerField( dword
                                                    microsecondsperfield );
    dword       __fastcall  FGetVideoPortID();
    void        __fastcall  FSetVideoPortID( dword videoportid );
TDDVideoPortConnect*
                __fastcall  FGetVideoPortType();                                //added get
    void        __fastcall  FSetVideoPortType( TDDVideoPortConnect*
                                                        videoportconnect );

private:

    DDVIDEOPORTDESC     fVideoPortDesc;

};
//---------------------------------------------------------------------------
#endif