// --------------------------------------------------------------------------
#ifndef TDDVideoPortInfoH
#define TDDVideoPortInfoH
// ==========================================================================
// File:            TDDVideoPortInfo.H
// Description:
//
// (c) 1998 A.S.C. Alternate Software Concepts, Sydney, Australia.
// All Rights Reserved. Refer to the file TDirectX_Licence.Txt for detailed
// licence & copyright information.
// ==========================================================================

// --------------------------------------------------------------------------
// include the basic TDirectDraw definitions, etc.
// --------------------------------------------------------------------------
#include "TDirectDrawInclude.h"
#include "TDirectDrawDefs.h"
#include "TDirectDrawErrors.h"

// --------------------------------------------------------------------------
// include the various DirectX Wrapper classes used by TDDVideoPortInfo
// --------------------------------------------------------------------------
#include "TDDPixelFormat.h"

// ==========================================================================
// Class:           TDDVideoPortInfo
// Description:     This object describes the transfer of video data to a
//                  surface
// Note:            This object is used with the
//                  TDirectDrawVideoPort::StartVideo method
// ==========================================================================
class TDDVideoPortInfo : public TPersistent
{
__published:
public:

// --------------------------------------------------------------------------
// Property:        OriginX
// Description:     X coordinate for the origin of the video data in the
//                  surface
// --------------------------------------------------------------------------
    __property      dword                   OriginX = { read=FGetOriginX,
                                                        write=FSetOriginX,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        OriginY
// Description:     Y coordinate for the origin of the video data in the
//                  surface
// --------------------------------------------------------------------------
    __property      dword                   OriginY = { read=FGetOriginY,
                                                        write=FSetOriginY,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        VPFlags
// Description:     Video port options
// --------------------------------------------------------------------------
    __property      dword                   VPFlags = { read=FGetVPFlags,
                                                        write=FSetVPFlags,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        Crop
// Description:     Cropping rectangle
// Note:            This property is optional
// --------------------------------------------------------------------------
    __property      TRect                      Crop = { read=FGetCrop,
                                                        write=FSetCrop,
                                                        nodefault };

// --------------------------------------------------------------------------
// Property:        PrescaleWidth
// Description:     Pre-scaling or zooming in the x direction
// Note:            This property is optional
// --------------------------------------------------------------------------
    __property      dword             PrescaleWidth = {
                                                    read=FGetPrescaleWidth,
                                                    write=FSetPrescaleWidth,
                                                    nodefault };

// --------------------------------------------------------------------------
// Property:        PrescaleHeight
// Description:     Pre-scaling or zooming in the y direction
// Note:            This property is optional
// --------------------------------------------------------------------------
    __property      dword            PrescaleHeight = {
                                                    read=FGetPrescaleHeight,
                                                    write=FSetPrescaleHeight,
                                                    nodefault };

// --------------------------------------------------------------------------
// Property:        InputFormat
// Description:     A TDDPixelFormat object describing the pixel format to be
//                  written to the video port
// Note:            This will often be identical to the surface's pixel
//                  format, but can differ if the video port is to perform
//                  conversion
// --------------------------------------------------------------------------
    __property      TDDPixelFormat*     InputFormat = { read=FGetInputFormat,   //added read
                                                        write=FSetInputFormat
                                                        ,nodefault };

// --------------------------------------------------------------------------
// Property:        VBIInputFormat
// Description:     A TDDPixelFormat object describing the input pixel format
//                  of the data within the vertical blanking interval
// --------------------------------------------------------------------------
    //
    __property      TDDPixelFormat*  VBIInputFormat = {
                                                    read=FGetVBIInputFormat,    //added read
                                                    write=FSetVBIInputFormat,
                                                    nodefault };

// --------------------------------------------------------------------------
// Property:        VBIOutputFormat
// Description:     A TDDPixelFormat object describing the output pixel
//                  format of the data within the vertical blanking interval
// --------------------------------------------------------------------------
    __property      TDDPixelFormat* VBIOutputFormat = {
                                                    read=FGetVBIOutputFormat,   //added read
                                                    write=FSetVBIOutputFormat
                                                    ,nodefault };

// --------------------------------------------------------------------------
// Property:        VBIHeight
// Description:     The amount of data within the vertical blanking interval,
//                  in scan lines
// --------------------------------------------------------------------------
    __property      dword                 VBIHeight = { read=FGetVBIHeight,
                                                        write=FSetVBIHeight,
                                                        nodefault };

// --------------------------------------------------------------------------
// Method:          Size
// Description:     This contains the size of the internal DDVIDEOPORTINFO
//                  structure
// --------------------------------------------------------------------------
    dword           __fastcall  Size();

// --------------------------------------------------------------------------
// Method:          Ptr
// Description:     This returns a pointer to the internal
//                  DDVIDEOPORTINFO structure.
// --------------------------------------------------------------------------
   DDVIDEOPORTINFO* __fastcall  Ptr();

// --------------------------------------------------------------------------
// Constructor & Destructor
// --------------------------------------------------------------------------
                    __fastcall  TDDVideoPortInfo();
    virtual         __fastcall  ~TDDVideoPortInfo();

// --------------------------------------------------------------------------
// End of the TDDBltBatch wrapper
// --------------------------------------------------------------------------

protected:

    dword           __fastcall  FGetOriginX();
    void            __fastcall  FSetOriginX( dword originx );
    dword           __fastcall  FGetOriginY();
    void            __fastcall  FSetOriginY( dword originy );
    dword           __fastcall  FGetVPFlags();
    void            __fastcall  FSetVPFlags( dword flags );
    TRect           __fastcall  FGetCrop();
    void            __fastcall  FSetCrop( TRect crop );
    dword           __fastcall  FGetPrescaleWidth();
    void            __fastcall  FSetPrescaleWidth( dword prescalewidth );
    dword           __fastcall  FGetPrescaleHeight();
    void            __fastcall  FSetPrescaleHeight( dword prescaleheight );
    TDDPixelFormat* __fastcall  FGetInputFormat();                              //added get
    void            __fastcall  FSetInputFormat( TDDPixelFormat*
                                                            inputformat );
    TDDPixelFormat* __fastcall  FGetVBIInputFormat();                           //added get
    void            __fastcall  FSetVBIInputFormat( TDDPixelFormat*
                                                            vbiinputformat );
    TDDPixelFormat* __fastcall  FGetVBIOutputFormat();                          //added get
    void            __fastcall  FSetVBIOutputFormat( TDDPixelFormat*
                                                        vbioutputformat );
    dword           __fastcall  FGetVBIHeight();
    void            __fastcall  FSetVBIHeight( dword vbiheight );

private:

    DDVIDEOPORTINFO  fVideoPortInfo;
};
//---------------------------------------------------------------------------
#endif
